==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/uikit/UIPopoverPresentationControllerDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIPopoverPresentationControllerDelegateAdapter/*</name>*/ 
    extends /*<extends>*/UIAdaptivePresentationControllerDelegateAdapter/*</extends>*/ 
    /*<implements>*/implements UIPopoverPresentationControllerDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("prepareForPopoverPresentation:")
    public void prepareForPopoverPresentation(UIPopoverPresentationController popoverPresentationController) {}
    @NotImplemented("popoverPresentationControllerShouldDismissPopover:")
    public boolean shouldDismissPopover(UIPopoverPresentationController popoverPresentationController) { return false; }
    @NotImplemented("popoverPresentationControllerDidDismissPopover:")
    public void didDismissPopover(UIPopoverPresentationController popoverPresentationController) {}
    @NotImplemented("popoverPresentationController:willRepositionPopoverToRect:inView:")
    public void willRepositionPopover(UIPopoverPresentationController popoverPresentationController, CGRect rect, UIView.UIViewPtr view) {}
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/uikit/UIPopoverPresentationControllerDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.fileprovider.*;
import org.robovm.apple.intents.*;
import org.robovm.apple.usernotifications.*;
import org.robovm.apple.linkpresentation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIPopoverPresentationControllerDelegateAdapter/*</name>*/ 
    extends /*<extends>*/UIAdaptivePresentationControllerDelegateAdapter/*</extends>*/ 
    /*<implements>*/implements UIPopoverPresentationControllerDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("prepareForPopoverPresentation:")
    public void prepareForPopoverPresentation(UIPopoverPresentationController popoverPresentationController) {}
    /**
     * @deprecated Deprecated in iOS 13.0. Use presentationControllerShouldDismiss:
     */
    @Deprecated
    @NotImplemented("popoverPresentationControllerShouldDismissPopover:")
    public boolean shouldDismissPopover(UIPopoverPresentationController popoverPresentationController) { return false; }
    /**
     * @deprecated Deprecated in iOS 13.0. Use presentationControllerDidDismiss:
     */
    @Deprecated
    @NotImplemented("popoverPresentationControllerDidDismissPopover:")
    public void didDismissPopover(UIPopoverPresentationController popoverPresentationController) {}
    @NotImplemented("popoverPresentationController:willRepositionPopoverToRect:inView:")
    public void willRepositionPopover(UIPopoverPresentationController popoverPresentationController, CGRect rect, UIView.UIViewPtr view) {}
    /*</methods>*/
}
